@@ -18,14 +18,14 @@ def main():
 
         kwargs = {
             "open_browser": False,
-            "allow_origin": "*",
+            "allow_origin": opt.allow_origin,
             "ip": opt.host,
             "notebook_dir": opt.workspace,
             "port": int(opt.port),
             "tornado_settings": {"headers": {"Access-Control-Allow-Origin": "*"}},
         }
 
-        if opt.token is None or opt.token == "":
+        if not opt.token:
             if not opt.random_token:
                 opt.token = read_or_generate_token()
                 kwargs["token"] = opt.token
